@@ -34,6 +34,22 @@ class Redis
       node_for(key).setnx(key, value, options)
     end
 
+    def redis_version
+      nodes.first.redis_version unless nodes.empty?
+    end
+
+    def supports_redis_version?(version)
+      if nodes.empty?
+        false
+      else
+        nodes.first.supports_redis_version?(version)
+      end
+    end
+
+    def setex(key, expiry, value, options = nil)
+      node_for(key).setex(key, expiry, value, options)
+    end
+
     private
       def _extend_namespace(options)
         @namespace = options[:namespace]
