@@ -1,9 +1,10 @@
 require 'redis/store/ttl'
 require 'redis/store/interface'
+require 'redis/store/redis_version'
 
 class Redis
   class Store < self
-    include Ttl, Interface
+    include Ttl, Interface, RedisVersion
 
     def initialize(options = { })
       super
@@ -28,7 +29,7 @@ class Redis
 
       def _extend_namespace(options)
         @namespace = options[:namespace]
-        extend Namespace if @namespace
+        extend Namespace
       end
   end
 end
