@@ -2,15 +2,15 @@ class Redis
   class Store < self
     module Marshalling
       def set(key, value, options = nil)
-        _marshal(value, options) { |value| super encode(key), encode(value), options }
+        _marshal(value, options) { |v| super encode(key), encode(v), options }
       end
 
       def setnx(key, value, options = nil)
-        _marshal(value, options) { |value| super encode(key), encode(value), options }
+        _marshal(value, options) { |v| super encode(key), encode(v), options }
       end
 
       def setex(key, expiry, value, options = nil)
-        _marshal(value, options) { |value| super encode(key), expiry, encode(value), options }
+        _marshal(value, options) { |v| super encode(key), expiry, encode(v), options }
       end
 
       def get(key, options = nil)
@@ -18,12 +18,22 @@ class Redis
       end
 
       def mget(*keys)
-        options = keys.flatten.pop if keys.flatten.last.is_a?(Hash)
+        options = keys.pop if keys.last.is_a?(Hash)
         super(*keys).map do |result|
           _unmarshal result, options
         end
       end
 
+      def mset(*args)
+        options = args.pop if args.length.odd?
+        updates = []
+        args.each_slice(2) do |(key, value)|
+          updates << encode(key)
+          _marshal(value, options) { |v| updates << encode(v) }
+        end
+        super(*updates)
+      end
+
       private
         def _marshal(val, options)
           yield marshal?(options) ? Marshal.dump(val) : val
