@@ -23,6 +23,12 @@ describe "Redis::Marshalling" do
     @store.get("rabbit").must_equal(@white_rabbit)
   end
 
+  it "marshals on multi set" do
+    @store.mset("rabbit", @white_rabbit, "rabbit2", @rabbit)
+    @store.get("rabbit").must_equal(@white_rabbit)
+    @store.get("rabbit2").must_equal(@rabbit)
+  end
+
   if RUBY_VERSION.match /1\.9/
     it "doesn't unmarshal on get if raw option is true" do
       @store.get("rabbit", :raw => true).must_equal("\x04\bU:\x0FOpenStruct{\x06:\tnameI\"\nbunny\x06:\x06EF")
@@ -38,6 +44,12 @@ describe "Redis::Marshalling" do
     @store.get("rabbit", :raw => true).must_equal(%(#<OpenStruct color="white">))
   end
 
+  it "doesn't marshal multi set if raw option is true" do
+    @store.mset("rabbit", @white_rabbit, "rabbit2", @rabbit, :raw => true)
+    @store.get("rabbit", :raw => true).must_equal(%(#<OpenStruct color="white">))
+    @store.get("rabbit2", :raw => true).must_equal(%(#<OpenStruct name="bunny">))
+  end
+
   it "doesn't unmarshal if get returns an empty string" do
     @store.set "empty_string", ""
     @store.get("empty_string").must_equal("")
@@ -67,9 +79,29 @@ describe "Redis::Marshalling" do
     @store.get("rabbit2").must_be_nil
   end
 
+  it "marshals setex (over a distributed store)" do
+    @store = Redis::DistributedStore.new [
+      {:host => "localhost", :port => "6380", :db => 0},
+      {:host => "localhost", :port => "6381", :db => 0}
+    ]
+    @store.setex "rabbit", 50, @white_rabbit
+    @store.get("rabbit").must_equal(@white_rabbit)
+  end
+
+  it "doesn't marshal setex if raw option is true (over a distributed store)" do
+    @store = Redis::DistributedStore.new [
+      {:host => "localhost", :port => "6380", :db => 0},
+      {:host => "localhost", :port => "6381", :db => 0}
+    ]
+    @store.setex "rabbit", 50, @white_rabbit, :raw => true
+    @store.get("rabbit", :raw => true).must_equal(%(#<OpenStruct color="white">))
+  end
+
   it "doesn't unmarshal on multi get" do
     @store.set "rabbit2", @white_rabbit
-    rabbit, rabbit2 = @store.mget "rabbit", "rabbit2"
+    rabbits = @store.mget "rabbit", "rabbit2"
+    rabbit, rabbit2 = rabbits
+    rabbits.length.must_equal(2)
     rabbit.must_equal(@rabbit)
     rabbit2.must_equal(@white_rabbit)
   end
